@@ -206,7 +206,7 @@ profRegr<-function(covNames, fixedEffectsNames, outcome="outcome", outcomeT=NA,
 			if (length(intersect(fixedEffectsNames,names(predict)))==length(fixedEffectsNames)) {
 				write(nPreds, paste(output,"_predictFull.txt",sep=""),ncolumns=1)
 				if (yModel=="Poisson" || yModel=="Binomial"||yModel=="Survival"){
-					write(t(as.matrix(predict[,c(outcome,outcomeT,fixedEffectsNames)])), paste(output,"_predictFull.txt",sep=""),append=T,ncolumns=(2+length(fixedEffectsNames)))
+					write(t(as.matrix(predict[,c(outcome,fixedEffectsNames,outcomeT)])), paste(output,"_predictFull.txt",sep=""),append=T,ncolumns=(2+length(fixedEffectsNames)))
 				} else {
 					write(t(as.matrix(predict[,c(outcome,fixedEffectsNames)])), paste(output,"_predictFull.txt",sep=""),append=T,ncolumns=(1+length(fixedEffectsNames)))				
 				}
@@ -1888,6 +1888,8 @@ calcPredictions<-function(riskProfObj,predictResponseFileName=NULL, doRaoBlackwe
 			predictedY[sweep,,]<-exp(lambda)
 		}else if(yModel=='Normal'){
 			predictedY[sweep,,]<-lambda
+		}else if(yModel=='Survival'){
+			predictedY[sweep,,]<-lambda
 		}else if(yModel=="Categorical"){
 			predictedY[sweep,,]<-exp(lambda)/rowSums(exp(lambda))
 		}
@@ -2607,7 +2609,7 @@ plotPredictions<-function(outfile,runInfoObj,predictions,logOR=FALSE){
 	if (yModel!="Bernoulli") stop("This function has been developed for Bernoulli response only.")
 	if (xModel=="Mixed") stop("This function has been developed for Discrete and Normal covariates only.")
 
-	if (runInfoObj$nFixedEffects>0) print("Note that fixed effects are not processed in this function.")
+	#if (runInfoObj$nFixedEffects>0) print("Note that fixed effects are not processed in this function.")
 	
 	predictResponseFileName = file.path(runInfoObj$directoryPath,paste(runInfoObj$fileStem,'_predict.txt',sep=''))
 	relScenarios<-read.table(predictResponseFileName,header=FALSE,skip=1)
@@ -2644,7 +2646,5 @@ plotPredictions<-function(outfile,runInfoObj,predictions,logOR=FALSE){
 		print(plotObj)
 	}
 	
-	dev.off()
-
 }
 
